==> xlniuxdata-vipgame-1.0.65-20170705.060154-89-sources.jar: com/xunlei/niux/data/vipgame/vo/sendgift/GameSendGiftSet.java <==
package com.xunlei.niux.data.vipgame.vo.sendgift;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by admin on 2017/6/14.
 */
@Table(tableName = "game_send_gift_set", pkFieldName = "seqId", pkFieldAssign = false)
public class GameSendGiftSet {
    private Integer seqId;
    private String gameId;
    private String url;
    private String giftKey;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;

    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getGiftKey() {
        return giftKey;
    }

    public void setGiftKey(String giftKey) {
        this.giftKey = giftKey;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170908.095959-108-sources.jar: com/xunlei/niux/data/vipgame/vo/sendgift/GameSendGiftSet.java <==
package com.xunlei.niux.data.vipgame.vo.sendgift;

import com.ferret.common.dao.annotation.Table;

/**
 * Created by admin on 2017/6/14.
 */
@Table(tableName = "game_send_gift_set", pkFieldName = "seqId", pkFieldAssign = false)
public class GameSendGiftSet {
    private Integer seqId;
    private String gameId;
    private String url;
    private String giftKey;
    private String inputBy;
    private String inputTime;
    private String editBy;
    private String editTime;
    private String status;

    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }

    public Integer getSeqId() {
        return seqId;
    }

    public void setSeqId(Integer seqId) {
        this.seqId = seqId;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getUrl() {
        return url;
    }

    public void setUrl(String url) {
        this.url = url;
    }

    public String getGiftKey() {
        return giftKey;
    }

    public void setGiftKey(String giftKey) {
        this.giftKey = giftKey;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }
}
